@@ -4,17 +4,10 @@
   Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
   Copyright (c) 2017, AMD Incorporated. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
-
 #include <PiPei.h>
 
 #include <Library/IoLib.h>
@@ -22,7 +15,6 @@
 #include <Library/BaseLib.h>
 #include <Library/PeiServicesTablePointerLib.h>
 
-
 /**
   Reads registers in the EFI CPU I/O space.
 
@@ -48,9 +40,9 @@ IoReadFifoWorker (
   IN      VOID                      *Buffer
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
-  EFI_STATUS                        Status;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
+  EFI_STATUS              Status;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -85,9 +77,9 @@ IoWriteFifoWorker (
   IN      VOID                      *Buffer
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
-  EFI_STATUS                        Status;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
+  EFI_STATUS              Status;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -114,17 +106,17 @@ IoWriteFifoWorker (
 UINT8
 EFIAPI
 IoRead8 (
-  IN      UINTN                     Port
+  IN      UINTN  Port
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
   ASSERT (CpuIo != NULL);
 
-  return CpuIo->IoRead8 (PeiServices, CpuIo, (UINT64) Port);
+  return CpuIo->IoRead8 (PeiServices, CpuIo, (UINT64)Port);
 }
 
 /**
@@ -145,18 +137,18 @@ IoRead8 (
 UINT8
 EFIAPI
 IoWrite8 (
-  IN      UINTN                     Port,
-  IN      UINT8                     Value
+  IN      UINTN  Port,
+  IN      UINT8  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
   ASSERT (CpuIo != NULL);
 
-  CpuIo->IoWrite8 (PeiServices, CpuIo, (UINT64) Port, Value);
+  CpuIo->IoWrite8 (PeiServices, CpuIo, (UINT64)Port, Value);
   return Value;
 }
 
@@ -178,11 +170,11 @@ IoWrite8 (
 UINT16
 EFIAPI
 IoRead16 (
-  IN      UINTN                     Port
+  IN      UINTN  Port
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -191,7 +183,7 @@ IoRead16 (
   // Make sure Port is aligned on a 16-bit boundary.
   //
   ASSERT ((Port & 1) == 0);
-  return CpuIo->IoRead16 (PeiServices, CpuIo, (UINT64) Port);
+  return CpuIo->IoRead16 (PeiServices, CpuIo, (UINT64)Port);
 }
 
 /**
@@ -213,12 +205,12 @@ IoRead16 (
 UINT16
 EFIAPI
 IoWrite16 (
-  IN      UINTN                     Port,
-  IN      UINT16                    Value
+  IN      UINTN   Port,
+  IN      UINT16  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -227,7 +219,7 @@ IoWrite16 (
   // Make sure Port is aligned on a 16-bit boundary.
   //
   ASSERT ((Port & 1) == 0);
-  CpuIo->IoWrite16 (PeiServices, CpuIo, (UINT64) Port, Value);
+  CpuIo->IoWrite16 (PeiServices, CpuIo, (UINT64)Port, Value);
   return Value;
 }
 
@@ -249,11 +241,11 @@ IoWrite16 (
 UINT32
 EFIAPI
 IoRead32 (
-  IN      UINTN                     Port
+  IN      UINTN  Port
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -262,7 +254,7 @@ IoRead32 (
   // Make sure Port is aligned on a 32-bit boundary.
   //
   ASSERT ((Port & 3) == 0);
-  return CpuIo->IoRead32 (PeiServices, CpuIo, (UINT64) Port);
+  return CpuIo->IoRead32 (PeiServices, CpuIo, (UINT64)Port);
 }
 
 /**
@@ -284,12 +276,12 @@ IoRead32 (
 UINT32
 EFIAPI
 IoWrite32 (
-  IN      UINTN                     Port,
-  IN      UINT32                    Value
+  IN      UINTN   Port,
+  IN      UINT32  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -298,7 +290,7 @@ IoWrite32 (
   // Make sure Port is aligned on a 32-bit boundary.
   //
   ASSERT ((Port & 3) == 0);
-  CpuIo->IoWrite32 (PeiServices, CpuIo, (UINT64) Port, Value);
+  CpuIo->IoWrite32 (PeiServices, CpuIo, (UINT64)Port, Value);
   return Value;
 }
 
@@ -320,11 +312,11 @@ IoWrite32 (
 UINT64
 EFIAPI
 IoRead64 (
-  IN      UINTN                     Port
+  IN      UINTN  Port
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -333,7 +325,7 @@ IoRead64 (
   // Make sure Port is aligned on a 64-bit boundary.
   //
   ASSERT ((Port & 7) == 0);
-  return CpuIo->IoRead64 (PeiServices, CpuIo, (UINT64) Port);
+  return CpuIo->IoRead64 (PeiServices, CpuIo, (UINT64)Port);
 }
 
 /**
@@ -355,12 +347,12 @@ IoRead64 (
 UINT64
 EFIAPI
 IoWrite64 (
-  IN      UINTN                     Port,
-  IN      UINT64                    Value
+  IN      UINTN   Port,
+  IN      UINT64  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -369,8 +361,8 @@ IoWrite64 (
   // Make sure Port is aligned on a 64-bit boundary.
   //
   ASSERT ((Port & 7) == 0);
-  CpuIo->IoWrite64 (PeiServices, CpuIo, (UINT64) Port, Value);
-  return Value;;
+  CpuIo->IoWrite64 (PeiServices, CpuIo, (UINT64)Port, Value);
+  return Value;
 }
 
 /**
@@ -393,9 +385,9 @@ IoWrite64 (
 VOID
 EFIAPI
 IoReadFifo8 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  OUT     VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  OUT     VOID   *Buffer
   )
 {
   IoReadFifoWorker (Port, EfiPeiCpuIoWidthFifoUint8, Count, Buffer);
@@ -421,9 +413,9 @@ IoReadFifo8 (
 VOID
 EFIAPI
 IoWriteFifo8 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  IN      VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  IN      VOID   *Buffer
   )
 {
   IoWriteFifoWorker (Port, EfiPeiCpuIoWidthFifoUint8, Count, Buffer);
@@ -449,9 +441,9 @@ IoWriteFifo8 (
 VOID
 EFIAPI
 IoReadFifo16 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  OUT     VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  OUT     VOID   *Buffer
   )
 {
   //
@@ -481,9 +473,9 @@ IoReadFifo16 (
 VOID
 EFIAPI
 IoWriteFifo16 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  IN      VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  IN      VOID   *Buffer
   )
 {
   //
@@ -513,9 +505,9 @@ IoWriteFifo16 (
 VOID
 EFIAPI
 IoReadFifo32 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  OUT     VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  OUT     VOID   *Buffer
   )
 {
   //
@@ -545,9 +537,9 @@ IoReadFifo32 (
 VOID
 EFIAPI
 IoWriteFifo32 (
-  IN      UINTN                     Port,
-  IN      UINTN                     Count,
-  IN      VOID                      *Buffer
+  IN      UINTN  Port,
+  IN      UINTN  Count,
+  IN      VOID   *Buffer
   )
 {
   //
@@ -574,17 +566,17 @@ IoWriteFifo32 (
 UINT8
 EFIAPI
 MmioRead8 (
-  IN      UINTN                     Address
+  IN      UINTN  Address
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
   ASSERT (CpuIo != NULL);
 
-  return CpuIo->MemRead8 (PeiServices, CpuIo, (UINT64) Address);
+  return CpuIo->MemRead8 (PeiServices, CpuIo, (UINT64)Address);
 }
 
 /**
@@ -605,18 +597,18 @@ MmioRead8 (
 UINT8
 EFIAPI
 MmioWrite8 (
-  IN      UINTN                     Address,
-  IN      UINT8                     Value
+  IN      UINTN  Address,
+  IN      UINT8  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
   ASSERT (CpuIo != NULL);
 
-  CpuIo->MemWrite8 (PeiServices, CpuIo, (UINT64) Address, Value);
+  CpuIo->MemWrite8 (PeiServices, CpuIo, (UINT64)Address, Value);
   return Value;
 }
 
@@ -638,11 +630,11 @@ MmioWrite8 (
 UINT16
 EFIAPI
 MmioRead16 (
-  IN      UINTN                     Address
+  IN      UINTN  Address
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -651,8 +643,7 @@ MmioRead16 (
   // Make sure Address is aligned on a 16-bit boundary.
   //
   ASSERT ((Address & 1) == 0);
-  return CpuIo->MemRead16 (PeiServices, CpuIo, (UINT64) Address);
-
+  return CpuIo->MemRead16 (PeiServices, CpuIo, (UINT64)Address);
 }
 
 /**
@@ -674,12 +665,12 @@ MmioRead16 (
 UINT16
 EFIAPI
 MmioWrite16 (
-  IN      UINTN                     Address,
-  IN      UINT16                    Value
+  IN      UINTN   Address,
+  IN      UINT16  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -688,7 +679,7 @@ MmioWrite16 (
   // Make sure Address is aligned on a 16-bit boundary.
   //
   ASSERT ((Address & 1) == 0);
-  CpuIo->MemWrite16 (PeiServices, CpuIo, (UINT64) Address, Value);
+  CpuIo->MemWrite16 (PeiServices, CpuIo, (UINT64)Address, Value);
   return Value;
 }
 
@@ -710,11 +701,11 @@ MmioWrite16 (
 UINT32
 EFIAPI
 MmioRead32 (
-  IN      UINTN                     Address
+  IN      UINTN  Address
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -723,8 +714,7 @@ MmioRead32 (
   // Make sure Address is aligned on a 32-bit boundary.
   //
   ASSERT ((Address & 3) == 0);
-  return CpuIo->MemRead32 (PeiServices, CpuIo, (UINT64) Address);
-
+  return CpuIo->MemRead32 (PeiServices, CpuIo, (UINT64)Address);
 }
 
 /**
@@ -746,12 +736,12 @@ MmioRead32 (
 UINT32
 EFIAPI
 MmioWrite32 (
-  IN      UINTN                     Address,
-  IN      UINT32                    Value
+  IN      UINTN   Address,
+  IN      UINT32  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -760,7 +750,7 @@ MmioWrite32 (
   // Make sure Address is aligned on a 32-bit boundary.
   //
   ASSERT ((Address & 3) == 0);
-  CpuIo->MemWrite32 (PeiServices, CpuIo, (UINT64) Address, Value);
+  CpuIo->MemWrite32 (PeiServices, CpuIo, (UINT64)Address, Value);
   return Value;
 }
 
@@ -782,11 +772,11 @@ MmioWrite32 (
 UINT64
 EFIAPI
 MmioRead64 (
-  IN      UINTN                     Address
+  IN      UINTN  Address
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -795,8 +785,7 @@ MmioRead64 (
   // Make sure Address is aligned on a 64-bit boundary.
   //
   ASSERT ((Address & (sizeof (UINT64) - 1)) == 0);
-  return CpuIo->MemRead64 (PeiServices, CpuIo, (UINT64) Address);
-
+  return CpuIo->MemRead64 (PeiServices, CpuIo, (UINT64)Address);
 }
 
 /**
@@ -816,12 +805,12 @@ MmioRead64 (
 UINT64
 EFIAPI
 MmioWrite64 (
-  IN      UINTN                     Address,
-  IN      UINT64                    Value
+  IN      UINTN   Address,
+  IN      UINT64  Value
   )
 {
-  CONST EFI_PEI_SERVICES            **PeiServices;
-  EFI_PEI_CPU_IO_PPI                *CpuIo;
+  CONST EFI_PEI_SERVICES  **PeiServices;
+  EFI_PEI_CPU_IO_PPI      *CpuIo;
 
   PeiServices = GetPeiServicesTablePointer ();
   CpuIo       = (*PeiServices)->CpuIo;
@@ -830,6 +819,6 @@ MmioWrite64 (
   // Make sure Address is aligned on a 64-bit boundary.
   //
   ASSERT ((Address & 7) == 0);
-  CpuIo->MemWrite64 (PeiServices, CpuIo, (UINT64) Address, Value);
+  CpuIo->MemWrite64 (PeiServices, CpuIo, (UINT64)Address, Value);
   return Value;
 }
