@@ -1,21 +1,16 @@
 /** @file
   The driver binding and service binding protocol for IP6 driver.
 
-  Copyright (c) 2009 - 2013, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2009 - 2019, Intel Corporation. All rights reserved.<BR>
+  (C) Copyright 2015 Hewlett-Packard Development Company, L.P.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
 #include "Ip6Impl.h"
 
-EFI_DRIVER_BINDING_PROTOCOL gIp6DriverBinding = {
+EFI_DRIVER_BINDING_PROTOCOL  gIp6DriverBinding = {
   Ip6DriverBindingSupported,
   Ip6DriverBindingStart,
   Ip6DriverBindingStop,
@@ -24,6 +19,39 @@ EFI_DRIVER_BINDING_PROTOCOL gIp6DriverBinding = {
   NULL
 };
 
+BOOLEAN  mIpSec2Installed = FALSE;
+
+/**
+   Callback function for IpSec2 Protocol install.
+
+   @param[in] Event           Event whose notification function is being invoked
+   @param[in] Context         Pointer to the notification function's context
+
+**/
+VOID
+EFIAPI
+IpSec2InstalledCallback (
+  IN EFI_EVENT  Event,
+  IN VOID       *Context
+  )
+{
+  EFI_STATUS  Status;
+
+  //
+  // Test if protocol was even found.
+  // Notification function will be called at least once.
+  //
+  Status = gBS->LocateProtocol (&gEfiIpSec2ProtocolGuid, NULL, (VOID **)&mIpSec);
+  if ((Status == EFI_SUCCESS) && (mIpSec != NULL)) {
+    //
+    // Close the event so it does not get called again.
+    //
+    gBS->CloseEvent (Event);
+
+    mIpSec2Installed = TRUE;
+  }
+}
+
 /**
   This is the declaration of an EFI image entry point. This entry point is
   the same for UEFI Applications, UEFI OS Loaders, and UEFI Drivers including
@@ -42,10 +70,20 @@ EFI_DRIVER_BINDING_PROTOCOL gIp6DriverBinding = {
 EFI_STATUS
 EFIAPI
 Ip6DriverEntryPoint (
-  IN EFI_HANDLE             ImageHandle,
-  IN EFI_SYSTEM_TABLE       *SystemTable
+  IN EFI_HANDLE        ImageHandle,
+  IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
+  VOID  *Registration;
+
+  EfiCreateProtocolNotifyEvent (
+    &gEfiIpSec2ProtocolGuid,
+    TPL_CALLBACK,
+    IpSec2InstalledCallback,
+    NULL,
+    &Registration
+    );
+
   return EfiLibInstallDriverBindingComponentName2 (
            ImageHandle,
            SystemTable,
@@ -105,12 +143,28 @@ Ip6DriverBindingSupported (
 **/
 EFI_STATUS
 Ip6CleanService (
-  IN IP6_SERVICE            *IpSb
+  IN IP6_SERVICE  *IpSb
   )
 {
-  EFI_STATUS                Status;
-  EFI_IPv6_ADDRESS          AllNodes;
-  IP6_NEIGHBOR_ENTRY        *NeighborCache;
+  EFI_STATUS          Status;
+  EFI_IPv6_ADDRESS    AllNodes;
+  IP6_NEIGHBOR_ENTRY  *NeighborCache;
+
+  IpSb->State = IP6_SERVICE_DESTROY;
+
+  if (IpSb->Timer != NULL) {
+    gBS->SetTimer (IpSb->Timer, TimerCancel, 0);
+    gBS->CloseEvent (IpSb->Timer);
+
+    IpSb->Timer = NULL;
+  }
+
+  if (IpSb->FasterTimer != NULL) {
+    gBS->SetTimer (IpSb->FasterTimer, TimerCancel, 0);
+    gBS->CloseEvent (IpSb->FasterTimer);
+
+    IpSb->FasterTimer = NULL;
+  }
 
   Ip6ConfigCleanInstance (&IpSb->Ip6ConfigInstance);
 
@@ -123,7 +177,7 @@ Ip6CleanService (
     Status = Ip6LeaveGroup (IpSb, &AllNodes);
     if (EFI_ERROR (Status)) {
       return Status;
-    }  
+    }
   }
 
   if (IpSb->DefaultInterface != NULL) {
@@ -154,11 +208,11 @@ Ip6CleanService (
       IpSb->Mnp->Cancel (IpSb->Mnp, NULL);
       IpSb->Mnp->Configure (IpSb->Mnp, NULL);
       gBS->CloseProtocol (
-            IpSb->MnpChildHandle,
-            &gEfiManagedNetworkProtocolGuid,
-            IpSb->Image,
-            IpSb->Controller
-            );
+             IpSb->MnpChildHandle,
+             &gEfiManagedNetworkProtocolGuid,
+             IpSb->Image,
+             IpSb->Controller
+             );
 
       IpSb->Mnp = NULL;
     }
@@ -177,19 +231,6 @@ Ip6CleanService (
     gBS->CloseEvent (IpSb->RecvRequest.MnpToken.Event);
   }
 
-  if (IpSb->Timer != NULL) {
-    gBS->SetTimer (IpSb->Timer, TimerCancel, 0);
-    gBS->CloseEvent (IpSb->Timer);
-
-    IpSb->Timer = NULL;
-  }
-
-  if (IpSb->FasterTimer != NULL) {
-    gBS->SetTimer (IpSb->FasterTimer, TimerCancel, 0);
-    gBS->CloseEvent (IpSb->FasterTimer);
-
-    IpSb->FasterTimer = NULL;
-  }
   //
   // Free the Neighbor Discovery resources
   //
@@ -216,16 +257,15 @@ Ip6CleanService (
 **/
 EFI_STATUS
 Ip6CreateService (
-  IN  EFI_HANDLE            Controller,
-  IN  EFI_HANDLE            ImageHandle,
-  OUT IP6_SERVICE           **Service
+  IN  EFI_HANDLE   Controller,
+  IN  EFI_HANDLE   ImageHandle,
+  OUT IP6_SERVICE  **Service
   )
 {
   IP6_SERVICE                           *IpSb;
   EFI_STATUS                            Status;
   EFI_MANAGED_NETWORK_COMPLETION_TOKEN  *MnpToken;
   EFI_MANAGED_NETWORK_CONFIG_DATA       *Config;
-  IP6_CONFIG_DATA_ITEM                  *DataItem;
 
   ASSERT (Service != NULL);
 
@@ -247,60 +287,60 @@ Ip6CreateService (
   IpSb->ServiceBinding.DestroyChild = Ip6ServiceBindingDestroyChild;
   IpSb->State                       = IP6_SERVICE_UNSTARTED;
 
-  IpSb->NumChildren                 = 0;
+  IpSb->NumChildren = 0;
   InitializeListHead (&IpSb->Children);
 
   InitializeListHead (&IpSb->Interfaces);
-  IpSb->DefaultInterface            = NULL;
-  IpSb->RouteTable                  = NULL;
+  IpSb->DefaultInterface = NULL;
+  IpSb->RouteTable       = NULL;
 
-  IpSb->RecvRequest.Signature       = IP6_LINK_RX_SIGNATURE;
-  IpSb->RecvRequest.CallBack        = NULL;
-  IpSb->RecvRequest.Context         = NULL;
-  MnpToken                          = &IpSb->RecvRequest.MnpToken;
-  MnpToken->Event                   = NULL;
-  MnpToken->Status                  = EFI_NOT_READY;
-  MnpToken->Packet.RxData           = NULL;
+  IpSb->RecvRequest.Signature = IP6_LINK_RX_SIGNATURE;
+  IpSb->RecvRequest.CallBack  = NULL;
+  IpSb->RecvRequest.Context   = NULL;
+  MnpToken                    = &IpSb->RecvRequest.MnpToken;
+  MnpToken->Event             = NULL;
+  MnpToken->Status            = EFI_NOT_READY;
+  MnpToken->Packet.RxData     = NULL;
 
   Ip6CreateAssembleTable (&IpSb->Assemble);
 
-  IpSb->MldCtrl.Mldv1QuerySeen      = 0;
+  IpSb->MldCtrl.Mldv1QuerySeen = 0;
   InitializeListHead (&IpSb->MldCtrl.Groups);
 
   ZeroMem (&IpSb->LinkLocalAddr, sizeof (EFI_IPv6_ADDRESS));
-  IpSb->LinkLocalOk                 = FALSE;
-  IpSb->LinkLocalDadFail            = FALSE;
-  IpSb->Dhcp6NeedStart              = FALSE;
-  IpSb->Dhcp6NeedInfoRequest        = FALSE;
+  IpSb->LinkLocalOk          = FALSE;
+  IpSb->LinkLocalDadFail     = FALSE;
+  IpSb->Dhcp6NeedStart       = FALSE;
+  IpSb->Dhcp6NeedInfoRequest = FALSE;
 
-  IpSb->CurHopLimit                 = IP6_HOP_LIMIT;
-  IpSb->LinkMTU                     = IP6_MIN_LINK_MTU;
-  IpSb->BaseReachableTime           = IP6_REACHABLE_TIME;
+  IpSb->CurHopLimit       = IP6_HOP_LIMIT;
+  IpSb->LinkMTU           = IP6_MIN_LINK_MTU;
+  IpSb->BaseReachableTime = IP6_REACHABLE_TIME;
   Ip6UpdateReachableTime (IpSb);
   //
   // RFC4861 RETRANS_TIMER: 1,000 milliseconds
   //
-  IpSb->RetransTimer                = IP6_RETRANS_TIMER;
+  IpSb->RetransTimer = IP6_RETRANS_TIMER;
 
-  IpSb->RoundRobin                  = 0;
+  IpSb->RoundRobin = 0;
 
   InitializeListHead (&IpSb->NeighborTable);
   InitializeListHead (&IpSb->DefaultRouterList);
   InitializeListHead (&IpSb->OnlinkPrefix);
   InitializeListHead (&IpSb->AutonomousPrefix);
 
-  IpSb->InterfaceIdLen              = IP6_IF_ID_LEN;
-  IpSb->InterfaceId                 = NULL;
+  IpSb->InterfaceIdLen = IP6_IF_ID_LEN;
+  IpSb->InterfaceId    = NULL;
 
-  IpSb->RouterAdvertiseReceived     = FALSE;
-  IpSb->SolicitTimer                = IP6_MAX_RTR_SOLICITATIONS;
-  IpSb->Ticks                       = 0;
+  IpSb->RouterAdvertiseReceived = FALSE;
+  IpSb->SolicitTimer            = IP6_MAX_RTR_SOLICITATIONS;
+  IpSb->Ticks                   = 0;
 
-  IpSb->Image                       = ImageHandle;
-  IpSb->Controller                  = Controller;
+  IpSb->Image      = ImageHandle;
+  IpSb->Controller = Controller;
 
-  IpSb->MnpChildHandle              = NULL;
-  IpSb->Mnp                         = NULL;
+  IpSb->MnpChildHandle = NULL;
+  IpSb->Mnp            = NULL;
 
   Config                            = &IpSb->MnpConfigData;
   Config->ReceivedQueueTimeoutValue = 0;
@@ -316,12 +356,12 @@ Ip6CreateService (
 
   ZeroMem (&IpSb->SnpMode, sizeof (EFI_SIMPLE_NETWORK_MODE));
 
-  IpSb->Timer                       = NULL;
-  IpSb->FasterTimer                 = NULL;
+  IpSb->Timer       = NULL;
+  IpSb->FasterTimer = NULL;
 
   ZeroMem (&IpSb->Ip6ConfigInstance, sizeof (IP6_CONFIG_INSTANCE));
 
-  IpSb->MacString                   = NULL;
+  IpSb->MacString = NULL;
 
   //
   // Create various resources. First create the route table, timer
@@ -369,7 +409,7 @@ Ip6CreateService (
   Status = gBS->OpenProtocol (
                   IpSb->MnpChildHandle,
                   &gEfiManagedNetworkProtocolGuid,
-                  (VOID **) (&IpSb->Mnp),
+                  (VOID **)(&IpSb->Mnp),
                   ImageHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_BY_DRIVER
@@ -395,6 +435,7 @@ Ip6CreateService (
     //
     IpSb->MaxPacketSize -= NET_VLAN_TAG_LEN;
   }
+
   IpSb->OldMaxPacketSize = IpSb->MaxPacketSize;
 
   //
@@ -439,30 +480,6 @@ Ip6CreateService (
     goto ON_ERROR;
   }
 
-  //
-  // If there is any manual address, set it.
-  //
-  DataItem = &IpSb->Ip6ConfigInstance.DataItem[Ip6ConfigDataTypeManualAddress];
-  if (DataItem->Data.Ptr != NULL) {
-    DataItem->SetData (
-                &IpSb->Ip6ConfigInstance,
-                DataItem->DataSize,
-                DataItem->Data.Ptr
-                );
-  }
-
-  //
-  // If there is any gateway address, set it.
-  //
-  DataItem = &IpSb->Ip6ConfigInstance.DataItem[Ip6ConfigDataTypeGateway];
-  if (DataItem->Data.Ptr != NULL) {
-    DataItem->SetData (
-                &IpSb->Ip6ConfigInstance,
-                DataItem->DataSize,
-                DataItem->Data.Ptr
-                );
-  }
-
   InsertHeadList (&IpSb->Interfaces, &IpSb->DefaultInterface->Link);
 
   *Service = IpSb;
@@ -474,7 +491,6 @@ ON_ERROR:
   return Status;
 }
 
-
 /**
   Start this driver on ControllerHandle.
 
@@ -483,7 +499,7 @@ ON_ERROR:
   @param[in]  RemainingDevicePath Optional parameter used to pick a specific child
                                   device to start.
 
-  @retval EFI_SUCCES              This driver is added to ControllerHandle.
+  @retval EFI_SUCCESS             This driver is added to ControllerHandle.
   @retval EFI_ALREADY_STARTED     This driver is already running on ControllerHandle.
   @retval other                   This driver does not support this device.
 
@@ -496,8 +512,14 @@ Ip6DriverBindingStart (
   IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath OPTIONAL
   )
 {
-  IP6_SERVICE               *IpSb;
-  EFI_STATUS                Status;
+  IP6_SERVICE              *IpSb;
+  EFI_STATUS               Status;
+  EFI_IP6_CONFIG_PROTOCOL  *Ip6Cfg;
+  IP6_CONFIG_DATA_ITEM     *DataItem;
+
+  IpSb     = NULL;
+  Ip6Cfg   = NULL;
+  DataItem = NULL;
 
   //
   // Test for the Ip6 service binding protocol
@@ -523,62 +545,132 @@ Ip6DriverBindingStart (
 
   ASSERT (IpSb != NULL);
 
+  Ip6Cfg = &IpSb->Ip6ConfigInstance.Ip6Config;
+
   //
-  // Install the Ip6ServiceBinding Protocol onto ControlerHandle
+  // Install the Ip6ServiceBinding Protocol onto ControllerHandle
   //
   Status = gBS->InstallMultipleProtocolInterfaces (
                   &ControllerHandle,
                   &gEfiIp6ServiceBindingProtocolGuid,
                   &IpSb->ServiceBinding,
                   &gEfiIp6ConfigProtocolGuid,
-                  &IpSb->Ip6ConfigInstance.Ip6Config,
+                  Ip6Cfg,
                   NULL
                   );
-
-  if (!EFI_ERROR (Status)) {
-    //
-    // ready to go: start the receiving and timer
-    //
-    Status = Ip6ReceiveFrame (Ip6AcceptFrame, IpSb);
-    if (EFI_ERROR (Status)) {
-      goto ON_ERROR;
-    }
-
-    //
-    // The timer expires every 100 (IP6_TIMER_INTERVAL_IN_MS) milliseconds.
-    //
-    Status = gBS->SetTimer (
-                    IpSb->FasterTimer,
-                    TimerPeriodic,
-                    TICKS_PER_MS * IP6_TIMER_INTERVAL_IN_MS
-                    );
-    if (EFI_ERROR (Status)) {
-      goto ON_ERROR;
-    }
-
-    //
-    // The timer expires every 1000 (IP6_ONE_SECOND_IN_MS) milliseconds.
-    //
-    Status = gBS->SetTimer (
-                    IpSb->Timer,
-                    TimerPeriodic,
-                    TICKS_PER_MS * IP6_ONE_SECOND_IN_MS
-                    );
-    if (EFI_ERROR (Status)) {
-      goto ON_ERROR;
-    }    
-
-    //
-    // Initialize the IP6 ID
-    //
-    mIp6Id = NET_RANDOM (NetRandomInitSeed ());
-
-    Ip6SetVariableData (IpSb);
-
-    return EFI_SUCCESS;
+  if (EFI_ERROR (Status)) {
+    goto FREE_SERVICE;
   }
 
-ON_ERROR:
+  //
+  // Read the config data from NV variable again.
+  // The default data can be changed by other drivers.
+  //
+  Status = Ip6ConfigReadConfigData (IpSb->MacString, &IpSb->Ip6ConfigInstance);
+  if (EFI_ERROR (Status)) {
+    goto UNINSTALL_PROTOCOL;
+  }
+
+  //
+  // If there is any default manual address, set it.
+  //
+  DataItem = &IpSb->Ip6ConfigInstance.DataItem[Ip6ConfigDataTypeManualAddress];
+  if (DataItem->Data.Ptr != NULL) {
+    Status = Ip6Cfg->SetData (
+                       Ip6Cfg,
+                       Ip6ConfigDataTypeManualAddress,
+                       DataItem->DataSize,
+                       DataItem->Data.Ptr
+                       );
+    if ((Status == EFI_INVALID_PARAMETER) || (Status == EFI_BAD_BUFFER_SIZE)) {
+      //
+      // Clean the invalid ManualAddress configuration.
+      //
+      Status = Ip6Cfg->SetData (
+                         Ip6Cfg,
+                         Ip6ConfigDataTypeManualAddress,
+                         0,
+                         NULL
+                         );
+      DEBUG ((DEBUG_WARN, "Ip6DriverBindingStart: Clean the invalid ManualAddress configuration.\n"));
+    }
+  }
+
+  //
+  // If there is any default gateway address, set it.
+  //
+  DataItem = &IpSb->Ip6ConfigInstance.DataItem[Ip6ConfigDataTypeGateway];
+  if (DataItem->Data.Ptr != NULL) {
+    Status = Ip6Cfg->SetData (
+                       Ip6Cfg,
+                       Ip6ConfigDataTypeGateway,
+                       DataItem->DataSize,
+                       DataItem->Data.Ptr
+                       );
+    if ((Status == EFI_INVALID_PARAMETER) || (Status == EFI_BAD_BUFFER_SIZE)) {
+      //
+      // Clean the invalid Gateway configuration.
+      //
+      Status = Ip6Cfg->SetData (
+                         Ip6Cfg,
+                         Ip6ConfigDataTypeGateway,
+                         0,
+                         NULL
+                         );
+      DEBUG ((DEBUG_WARN, "Ip6DriverBindingStart: Clean the invalid Gateway configuration.\n"));
+    }
+  }
+
+  //
+  // ready to go: start the receiving and timer
+  //
+  Status = Ip6ReceiveFrame (Ip6AcceptFrame, IpSb);
+  if (EFI_ERROR (Status)) {
+    goto UNINSTALL_PROTOCOL;
+  }
+
+  //
+  // The timer expires every 100 (IP6_TIMER_INTERVAL_IN_MS) milliseconds.
+  //
+  Status = gBS->SetTimer (
+                  IpSb->FasterTimer,
+                  TimerPeriodic,
+                  TICKS_PER_MS * IP6_TIMER_INTERVAL_IN_MS
+                  );
+  if (EFI_ERROR (Status)) {
+    goto UNINSTALL_PROTOCOL;
+  }
+
+  //
+  // The timer expires every 1000 (IP6_ONE_SECOND_IN_MS) milliseconds.
+  //
+  Status = gBS->SetTimer (
+                  IpSb->Timer,
+                  TimerPeriodic,
+                  TICKS_PER_MS * IP6_ONE_SECOND_IN_MS
+                  );
+  if (EFI_ERROR (Status)) {
+    goto UNINSTALL_PROTOCOL;
+  }
+
+  //
+  // Initialize the IP6 ID
+  //
+  mIp6Id = NET_RANDOM (NetRandomInitSeed ());
+
+  return EFI_SUCCESS;
+
+UNINSTALL_PROTOCOL:
+  gBS->UninstallMultipleProtocolInterfaces (
+         ControllerHandle,
+         &gEfiIp6ServiceBindingProtocolGuid,
+         &IpSb->ServiceBinding,
+         &gEfiIp6ConfigProtocolGuid,
+         Ip6Cfg,
+         NULL
+         );
+
+FREE_SERVICE:
   Ip6CleanService (IpSb);
   FreePool (IpSb);
   return Status;
@@ -586,7 +678,7 @@ ON_ERROR:
 
 /**
   Callback function which provided by user to remove one node in NetDestroyLinkList process.
-  
+
   @param[in]    Entry           The entry to be removed.
   @param[in]    Context         Pointer to the callback context corresponds to the Context in NetDestroyLinkList.
 
@@ -597,8 +689,8 @@ ON_ERROR:
 EFI_STATUS
 EFIAPI
 Ip6DestroyChildEntryInHandleBuffer (
-  IN LIST_ENTRY         *Entry,
-  IN VOID               *Context
+  IN LIST_ENTRY  *Entry,
+  IN VOID        *Context
   )
 {
   IP6_PROTOCOL                  *IpInstance;
@@ -606,14 +698,14 @@ Ip6DestroyChildEntryInHandleBuffer (
   UINTN                         NumberOfChildren;
   EFI_HANDLE                    *ChildHandleBuffer;
 
-  if (Entry == NULL || Context == NULL) {
+  if ((Entry == NULL) || (Context == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
-  IpInstance = NET_LIST_USER_STRUCT_S (Entry, IP6_PROTOCOL, Link, IP6_PROTOCOL_SIGNATURE);
-  ServiceBinding    = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *) Context)->ServiceBinding;
-  NumberOfChildren  = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *) Context)->NumberOfChildren;
-  ChildHandleBuffer = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *) Context)->ChildHandleBuffer;
+  IpInstance        = NET_LIST_USER_STRUCT_S (Entry, IP6_PROTOCOL, Link, IP6_PROTOCOL_SIGNATURE);
+  ServiceBinding    = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *)Context)->ServiceBinding;
+  NumberOfChildren  = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *)Context)->NumberOfChildren;
+  ChildHandleBuffer = ((IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT *)Context)->ChildHandleBuffer;
 
   if (!NetIsInHandleBuffer (IpInstance->Handle, NumberOfChildren, ChildHandleBuffer)) {
     return EFI_SUCCESS;
@@ -645,14 +737,14 @@ Ip6DriverBindingStop (
   IN  EFI_HANDLE                   *ChildHandleBuffer OPTIONAL
   )
 {
-  EFI_SERVICE_BINDING_PROTOCOL            *ServiceBinding;
-  IP6_SERVICE                             *IpSb;
-  EFI_HANDLE                              NicHandle;
-  EFI_STATUS                              Status;
-  LIST_ENTRY                              *List;
-  INTN                                    State;
-  BOOLEAN                                 IsDhcp6;
-  IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT Context;
+  EFI_SERVICE_BINDING_PROTOCOL             *ServiceBinding;
+  IP6_SERVICE                              *IpSb;
+  EFI_HANDLE                               NicHandle;
+  EFI_STATUS                               Status;
+  LIST_ENTRY                               *List;
+  INTN                                     State;
+  BOOLEAN                                  IsDhcp6;
+  IP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT  Context;
 
   IsDhcp6   = FALSE;
   NicHandle = NetLibGetNicHandle (ControllerHandle, &gEfiManagedNetworkProtocolGuid);
@@ -668,7 +760,7 @@ Ip6DriverBindingStop (
   Status = gBS->OpenProtocol (
                   NicHandle,
                   &gEfiIp6ServiceBindingProtocolGuid,
-                  (VOID **) &ServiceBinding,
+                  (VOID **)&ServiceBinding,
                   This->DriverBindingHandle,
                   NicHandle,
                   EFI_OPEN_PROTOCOL_GET_PROTOCOL
@@ -687,25 +779,18 @@ Ip6DriverBindingStop (
     //
     // NumberOfChildren is not zero, destroy the IP6 children instances in ChildHandleBuffer.
     //
-    List = &IpSb->Children;
+    List                      = &IpSb->Children;
     Context.ServiceBinding    = ServiceBinding;
     Context.NumberOfChildren  = NumberOfChildren;
     Context.ChildHandleBuffer = ChildHandleBuffer;
-    Status = NetDestroyLinkList (
-               List,
-               Ip6DestroyChildEntryInHandleBuffer,
-               &Context,
-               NULL
-               );
+    Status                    = NetDestroyLinkList (
+                                  List,
+                                  Ip6DestroyChildEntryInHandleBuffer,
+                                  &Context,
+                                  NULL
+                                  );
   } else if (IsListEmpty (&IpSb->Children)) {
-    State           = IpSb->State;
-    IpSb->State     = IP6_SERVICE_DESTROY;
-
-    //
-    // Clear the variable data.
-    //
-    Ip6ClearVariableData (IpSb);
-
+    State  = IpSb->State;
     Status = Ip6CleanService (IpSb);
     if (EFI_ERROR (Status)) {
       IpSb->State = State;
@@ -724,12 +809,11 @@ Ip6DriverBindingStop (
     FreePool (IpSb);
     Status = EFI_SUCCESS;
   }
-  
+
 Exit:
   return Status;
 }
 
-
 /**
   Creates a child handle with a set of I/O services.
 
@@ -739,8 +823,8 @@ Exit:
                                  is not NULL, then the I/O services are added to
                                  the existing child handle.
 
-  @retval EFI_SUCCES             The child handle was created with the I/O services.
-  @retval EFI_OUT_OF_RESOURCES   There are not enough resources availabe to create
+  @retval EFI_SUCCESS            The child handle was created with the I/O services.
+  @retval EFI_OUT_OF_RESOURCES   There are not enough resources available to create
                                  the child.
   @retval other                  The child handle was not created.
 
@@ -752,17 +836,17 @@ Ip6ServiceBindingCreateChild (
   IN EFI_HANDLE                    *ChildHandle
   )
 {
-  IP6_SERVICE               *IpSb;
-  IP6_PROTOCOL              *IpInstance;
-  EFI_TPL                   OldTpl;
-  EFI_STATUS                Status;
-  VOID                      *Mnp;
+  IP6_SERVICE   *IpSb;
+  IP6_PROTOCOL  *IpInstance;
+  EFI_TPL       OldTpl;
+  EFI_STATUS    Status;
+  VOID          *Mnp;
 
   if ((This == NULL) || (ChildHandle == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
-  IpSb       = IP6_SERVICE_FROM_PROTOCOL (This);
+  IpSb = IP6_SERVICE_FROM_PROTOCOL (This);
 
   if (IpSb->LinkLocalDadFail) {
     return EFI_DEVICE_ERROR;
@@ -797,14 +881,14 @@ Ip6ServiceBindingCreateChild (
   Status = gBS->OpenProtocol (
                   IpSb->MnpChildHandle,
                   &gEfiManagedNetworkProtocolGuid,
-                  (VOID **) &Mnp,
+                  (VOID **)&Mnp,
                   gIp6DriverBinding.DriverBindingHandle,
                   IpInstance->Handle,
                   EFI_OPEN_PROTOCOL_BY_CHILD_CONTROLLER
                   );
   if (EFI_ERROR (Status)) {
     gBS->UninstallMultipleProtocolInterfaces (
-           ChildHandle,
+           *ChildHandle,
            &gEfiIp6ProtocolGuid,
            &IpInstance->Ip6Proto,
            NULL
@@ -826,7 +910,6 @@ Ip6ServiceBindingCreateChild (
 ON_ERROR:
 
   if (EFI_ERROR (Status)) {
-
     Ip6CleanProtocol (IpInstance);
 
     FreePool (IpInstance);
@@ -841,7 +924,7 @@ ON_ERROR:
   @param[in]  This               Protocol instance pointer.
   @param[in]  ChildHandle        Handle of the child to destroy.
 
-  @retval EFI_SUCCES             The I/O services were removed from the child
+  @retval EFI_SUCCESS            The I/O services were removed from the child
                                  handle.
   @retval EFI_UNSUPPORTED        The child handle does not support the I/O services
                                   that are being removed.
@@ -858,11 +941,11 @@ Ip6ServiceBindingDestroyChild (
   IN EFI_HANDLE                    ChildHandle
   )
 {
-  EFI_STATUS                Status;
-  IP6_SERVICE               *IpSb;
-  IP6_PROTOCOL              *IpInstance;
-  EFI_IP6_PROTOCOL          *Ip6;
-  EFI_TPL                   OldTpl;
+  EFI_STATUS        Status;
+  IP6_SERVICE       *IpSb;
+  IP6_PROTOCOL      *IpInstance;
+  EFI_IP6_PROTOCOL  *Ip6;
+  EFI_TPL           OldTpl;
 
   if ((This == NULL) || (ChildHandle == NULL)) {
     return EFI_INVALID_PARAMETER;
@@ -871,12 +954,12 @@ Ip6ServiceBindingDestroyChild (
   //
   // Retrieve the private context data structures
   //
-  IpSb   = IP6_SERVICE_FROM_PROTOCOL (This);
+  IpSb = IP6_SERVICE_FROM_PROTOCOL (This);
 
   Status = gBS->OpenProtocol (
                   ChildHandle,
                   &gEfiIp6ProtocolGuid,
-                  (VOID **) &Ip6,
+                  (VOID **)&Ip6,
                   gIp6DriverBinding.DriverBindingHandle,
                   ChildHandle,
                   EFI_OPEN_PROTOCOL_GET_PROTOCOL
@@ -921,14 +1004,14 @@ Ip6ServiceBindingDestroyChild (
   // Uninstall the IP6 protocol first. Many thing happens during
   // this:
   // 1. The consumer of the IP6 protocol will be stopped if it
-  // opens the protocol BY_DRIVER. For eaxmple, if MNP driver is
+  // opens the protocol BY_DRIVER. For example, if MNP driver is
   // stopped, IP driver's stop function will be called, and uninstall
   // EFI_IP6_PROTOCOL will trigger the UDP's stop function. This
   // makes it possible to create the network stack bottom up, and
   // stop it top down.
   // 2. the upper layer will recycle the received packet. The recycle
   // event's TPL is higher than this function. The recycle events
-  // will be called back before preceeding. If any packets not recycled,
+  // will be called back before preceding. If any packets not recycled,
   // that means there is a resource leak.
   //
   gBS->RestoreTPL (OldTpl);
@@ -943,9 +1026,6 @@ Ip6ServiceBindingDestroyChild (
   }
 
   Status = Ip6CleanProtocol (IpInstance);
-
-  Ip6SetVariableData (IpSb);
-
   if (EFI_ERROR (Status)) {
     gBS->InstallMultipleProtocolInterfaces (
            &ChildHandle,
