@@ -2,13 +2,7 @@
   Header file for compression routine.
 
   Copyright (c) 2005 - 2011, Intel Corporation. All rights reserved.<BR>
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -24,7 +18,7 @@
   @param[in, out]  DstSize       On input the size (in bytes) of DstBuffer, on
                                  return the number of bytes placed in DstBuffer.
 
-  @retval EFI_SUCCESS           The compression was sucessful.
+  @retval EFI_SUCCESS           The compression was successful.
   @retval EFI_BUFFER_TOO_SMALL  The buffer was too small.  DstSize is required.
 **/
 EFI_STATUS
@@ -36,4 +30,3 @@ Compress (
   );
 
 #endif
-
