@@ -1,7 +1,7 @@
 /** @file
   Unit tests of the MtrrLib instance of the MtrrLib class
 
-  Copyright (c) 2018 - 2020, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2018 - 2023, Intel Corporation. All rights reserved.<BR>
   SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
@@ -12,13 +12,15 @@ MTRR_MEMORY_CACHE_TYPE  mMemoryCacheTypes[] = {
   CacheUncacheable, CacheWriteCombining, CacheWriteThrough, CacheWriteProtected, CacheWriteBack
 };
 
-UINT64                           mFixedMtrrsValue[MTRR_NUMBER_OF_FIXED_MTRR];
-MSR_IA32_MTRR_PHYSBASE_REGISTER  mVariableMtrrsPhysBase[MTRR_NUMBER_OF_VARIABLE_MTRR];
-MSR_IA32_MTRR_PHYSMASK_REGISTER  mVariableMtrrsPhysMask[MTRR_NUMBER_OF_VARIABLE_MTRR];
-MSR_IA32_MTRR_DEF_TYPE_REGISTER  mDefTypeMsr;
-MSR_IA32_MTRRCAP_REGISTER        mMtrrCapMsr;
-CPUID_VERSION_INFO_EDX           mCpuidVersionInfoEdx;
-CPUID_VIR_PHY_ADDRESS_SIZE_EAX   mCpuidVirPhyAddressSizeEax;
+UINT64                                       mFixedMtrrsValue[MTRR_NUMBER_OF_FIXED_MTRR];
+MSR_IA32_MTRR_PHYSBASE_REGISTER              mVariableMtrrsPhysBase[MTRR_NUMBER_OF_VARIABLE_MTRR];
+MSR_IA32_MTRR_PHYSMASK_REGISTER              mVariableMtrrsPhysMask[MTRR_NUMBER_OF_VARIABLE_MTRR];
+MSR_IA32_MTRR_DEF_TYPE_REGISTER              mDefTypeMsr;
+MSR_IA32_MTRRCAP_REGISTER                    mMtrrCapMsr;
+MSR_IA32_TME_ACTIVATE_REGISTER               mTmeActivateMsr;
+CPUID_VERSION_INFO_EDX                       mCpuidVersionInfoEdx;
+CPUID_STRUCTURED_EXTENDED_FEATURE_FLAGS_ECX  mCpuidExtendedFeatureFlagsEcx;
+CPUID_VIR_PHY_ADDRESS_SIZE_EAX               mCpuidVirPhyAddressSizeEax;
 
 BOOLEAN       mRandomInput;
 UINTN         mNumberIndex = 0;
@@ -41,7 +43,6 @@ Rand (
   if (mRandomInput) {
     return rand ();
   } else {
-    DEBUG ((DEBUG_INFO, "random: %d\n", mNumberIndex));
     return mNumbers[mNumberIndex++ % (mNumberCount - 1)];
   }
 }
@@ -86,6 +87,94 @@ GenerateRandomNumbers (
   fclose (File);
 }
 
+/**
+  Retrieves CPUID information using an extended leaf identifier.
+
+  Executes the CPUID instruction with EAX set to the value specified by Index
+  and ECX set to the value specified by SubIndex. This function always returns
+  Index. This function is only available on IA-32 and x64.
+
+  If Eax is not NULL, then the value of EAX after CPUID is returned in Eax.
+  If Ebx is not NULL, then the value of EBX after CPUID is returned in Ebx.
+  If Ecx is not NULL, then the value of ECX after CPUID is returned in Ecx.
+  If Edx is not NULL, then the value of EDX after CPUID is returned in Edx.
+
+  @param  Index     The 32-bit value to load into EAX prior to invoking the
+                    CPUID instruction.
+  @param  SubIndex  The 32-bit value to load into ECX prior to invoking the
+                    CPUID instruction.
+  @param  Eax       The pointer to the 32-bit EAX value returned by the CPUID
+                    instruction. This is an optional parameter that may be
+                    NULL.
+  @param  Ebx       The pointer to the 32-bit EBX value returned by the CPUID
+                    instruction. This is an optional parameter that may be
+                    NULL.
+  @param  Ecx       The pointer to the 32-bit ECX value returned by the CPUID
+                    instruction. This is an optional parameter that may be
+                    NULL.
+  @param  Edx       The pointer to the 32-bit EDX value returned by the CPUID
+                    instruction. This is an optional parameter that may be
+                    NULL.
+
+  @return Index.
+
+**/
+UINT32
+EFIAPI
+UnitTestMtrrLibAsmCpuidEx (
+  IN      UINT32  Index,
+  IN      UINT32  SubIndex,
+  OUT     UINT32  *Eax   OPTIONAL,
+  OUT     UINT32  *Ebx   OPTIONAL,
+  OUT     UINT32  *Ecx   OPTIONAL,
+  OUT     UINT32  *Edx   OPTIONAL
+  )
+{
+  switch (Index) {
+    case CPUID_SIGNATURE:
+      if (Eax != NULL) {
+        *Eax = CPUID_STRUCTURED_EXTENDED_FEATURE_FLAGS;
+      }
+
+      return Index;
+      break;
+    case CPUID_VERSION_INFO:
+      if (Edx != NULL) {
+        *Edx = mCpuidVersionInfoEdx.Uint32;
+      }
+
+      return Index;
+      break;
+    case CPUID_STRUCTURED_EXTENDED_FEATURE_FLAGS:
+      if (Ecx != NULL) {
+        *Ecx = mCpuidExtendedFeatureFlagsEcx.Uint32;
+      }
+
+      return Index;
+      break;
+    case CPUID_EXTENDED_FUNCTION:
+      if (Eax != NULL) {
+        *Eax = CPUID_VIR_PHY_ADDRESS_SIZE;
+      }
+
+      return Index;
+      break;
+    case CPUID_VIR_PHY_ADDRESS_SIZE:
+      if (Eax != NULL) {
+        *Eax = mCpuidVirPhyAddressSizeEax.Uint32;
+      }
+
+      return Index;
+      break;
+  }
+
+  //
+  // Should never fall through to here
+  //
+  ASSERT (FALSE);
+  return Index;
+}
+
 /**
   Retrieves CPUID information.
 
@@ -121,35 +210,7 @@ UnitTestMtrrLibAsmCpuid (
   OUT     UINT32  *Edx   OPTIONAL
   )
 {
-  switch (Index) {
-    case CPUID_VERSION_INFO:
-      if (Edx != NULL) {
-        *Edx = mCpuidVersionInfoEdx.Uint32;
-      }
-
-      return Index;
-      break;
-    case CPUID_EXTENDED_FUNCTION:
-      if (Eax != NULL) {
-        *Eax = CPUID_VIR_PHY_ADDRESS_SIZE;
-      }
-
-      return Index;
-      break;
-    case CPUID_VIR_PHY_ADDRESS_SIZE:
-      if (Eax != NULL) {
-        *Eax = mCpuidVirPhyAddressSizeEax.Uint32;
-      }
-
-      return Index;
-      break;
-  }
-
-  //
-  // Should never fall through to here
-  //
-  ASSERT (FALSE);
-  return Index;
+  return UnitTestMtrrLibAsmCpuidEx (Index, 0, Eax, Ebx, Ecx, Edx);
 }
 
 /**
@@ -174,8 +235,11 @@ UnitTestMtrrLibAsmReadMsr64 (
 {
   UINT32  Index;
 
+  UT_ASSERT_EQUAL (mCpuidVersionInfoEdx.Bits.MTRR, 1);
+
   for (Index = 0; Index < ARRAY_SIZE (mFixedMtrrsValue); Index++) {
     if (MsrIndex == mFixedMtrrsIndex[Index]) {
+      UT_ASSERT_EQUAL (mMtrrCapMsr.Bits.FIX, 1);
       return mFixedMtrrsValue[Index];
     }
   }
@@ -183,6 +247,7 @@ UnitTestMtrrLibAsmReadMsr64 (
   if ((MsrIndex >= MSR_IA32_MTRR_PHYSBASE0) &&
       (MsrIndex <= MSR_IA32_MTRR_PHYSMASK0 + (MTRR_NUMBER_OF_VARIABLE_MTRR << 1)))
   {
+    UT_ASSERT_TRUE (((MsrIndex - MSR_IA32_MTRR_PHYSBASE0) >> 1) < mMtrrCapMsr.Bits.VCNT);
     if (MsrIndex % 2 == 0) {
       Index = (MsrIndex - MSR_IA32_MTRR_PHYSBASE0) >> 1;
       return mVariableMtrrsPhysBase[Index].Uint64;
@@ -200,6 +265,10 @@ UnitTestMtrrLibAsmReadMsr64 (
     return mMtrrCapMsr.Uint64;
   }
 
+  if (MsrIndex == MSR_IA32_TME_ACTIVATE) {
+    return mTmeActivateMsr.Uint64;
+  }
+
   //
   // Should never fall through to here
   //
@@ -233,8 +302,11 @@ UnitTestMtrrLibAsmWriteMsr64 (
 {
   UINT32  Index;
 
+  UT_ASSERT_EQUAL (mCpuidVersionInfoEdx.Bits.MTRR, 1);
+
   for (Index = 0; Index < ARRAY_SIZE (mFixedMtrrsValue); Index++) {
     if (MsrIndex == mFixedMtrrsIndex[Index]) {
+      UT_ASSERT_EQUAL (mMtrrCapMsr.Bits.FIX, 1);
       mFixedMtrrsValue[Index] = Value;
       return Value;
     }
@@ -243,6 +315,7 @@ UnitTestMtrrLibAsmWriteMsr64 (
   if ((MsrIndex >= MSR_IA32_MTRR_PHYSBASE0) &&
       (MsrIndex <= MSR_IA32_MTRR_PHYSMASK0 + (MTRR_NUMBER_OF_VARIABLE_MTRR << 1)))
   {
+    UT_ASSERT_TRUE (((MsrIndex - MSR_IA32_MTRR_PHYSBASE0) >> 1) < mMtrrCapMsr.Bits.VCNT);
     if (MsrIndex % 2 == 0) {
       Index                                = (MsrIndex - MSR_IA32_MTRR_PHYSBASE0) >> 1;
       mVariableMtrrsPhysBase[Index].Uint64 = Value;
@@ -255,6 +328,10 @@ UnitTestMtrrLibAsmWriteMsr64 (
   }
 
   if (MsrIndex == MSR_IA32_MTRR_DEF_TYPE) {
+    if (((MSR_IA32_MTRR_DEF_TYPE_REGISTER *)&Value)->Bits.FE == 1) {
+      UT_ASSERT_EQUAL (mMtrrCapMsr.Bits.FIX, 1);
+    }
+
     mDefTypeMsr.Uint64 = Value;
     return Value;
   }
@@ -287,17 +364,12 @@ InitializeMtrrRegs (
   SetMem (mFixedMtrrsValue, sizeof (mFixedMtrrsValue), SystemParameter->DefaultCacheType);
 
   for (Index = 0; Index < ARRAY_SIZE (mVariableMtrrsPhysBase); Index++) {
-    mVariableMtrrsPhysBase[Index].Uint64         = 0;
-    mVariableMtrrsPhysBase[Index].Bits.Type      = SystemParameter->DefaultCacheType;
-    mVariableMtrrsPhysBase[Index].Bits.Reserved1 = 0;
-
-    mVariableMtrrsPhysMask[Index].Uint64         = 0;
-    mVariableMtrrsPhysMask[Index].Bits.V         = 0;
-    mVariableMtrrsPhysMask[Index].Bits.Reserved1 = 0;
+    mVariableMtrrsPhysBase[Index].Uint64 = 0;
+    mVariableMtrrsPhysMask[Index].Uint64 = 0;
   }
 
   mDefTypeMsr.Bits.E         = 1;
-  mDefTypeMsr.Bits.FE        = 1;
+  mDefTypeMsr.Bits.FE        = 0;
   mDefTypeMsr.Bits.Type      = SystemParameter->DefaultCacheType;
   mDefTypeMsr.Bits.Reserved1 = 0;
   mDefTypeMsr.Bits.Reserved2 = 0;
@@ -317,10 +389,22 @@ InitializeMtrrRegs (
   //
   // Hook BaseLib functions used by MtrrLib that require some emulation.
   //
-  gUnitTestHostBaseLib.X86->AsmCpuid      = UnitTestMtrrLibAsmCpuid;
+  gUnitTestHostBaseLib.X86->AsmCpuid   = UnitTestMtrrLibAsmCpuid;
+  gUnitTestHostBaseLib.X86->AsmCpuidEx = UnitTestMtrrLibAsmCpuidEx;
+
   gUnitTestHostBaseLib.X86->AsmReadMsr64  = UnitTestMtrrLibAsmReadMsr64;
   gUnitTestHostBaseLib.X86->AsmWriteMsr64 = UnitTestMtrrLibAsmWriteMsr64;
 
+  if (SystemParameter->MkTmeKeyidBits != 0) {
+    mCpuidExtendedFeatureFlagsEcx.Bits.TME_EN = 1;
+    mTmeActivateMsr.Bits.TmeEnable            = 1;
+    mTmeActivateMsr.Bits.MkTmeKeyidBits       = SystemParameter->MkTmeKeyidBits;
+  } else {
+    mCpuidExtendedFeatureFlagsEcx.Bits.TME_EN = 0;
+    mTmeActivateMsr.Bits.TmeEnable            = 0;
+    mTmeActivateMsr.Bits.MkTmeKeyidBits       = 0;
+  }
+
   return UNIT_TEST_PASSED;
 }
 
